import "./tasks/indelNorm.wdl" as indelNorm
import "./tasks/SepSnvIndel.wdl" as SepSnvIndel
import "./tasks/ExtractVCFinfo.wdl" as ExtractVCFinfo
import "./tasks/oneClass.wdl" as oneClass
import "./tasks/SepTrueFalse.wdl" as SepTrueFalse
import "./tasks/vcfeval.wdl" as vcfeval



workflow {{ project_name }} {
	File nist_vcf
	File giab_bed
	File giab_snv
	File giab_snv_idx
	File giab_indel
	File giab_indel_idx
	File snv_train
	File indel_train
	File ref_dir
	File sdf
	String kernel
	String nu
	String nist_sample_name
	String cluster_config
	String disk_size
	String fasta

	call indelNorm.indelNorm as indelNorm {
			input: 
			nist_vcf=nist_vcf,
			sampleName=nist_sample_name,
			ref_dir=ref_dir,
			fasta=fasta,
			disk_size=disk_size,
			cluster_config=cluster_config
		}

	call SepSnvIndel.SepSnvIndel as SepSnvIndel {
			input:
			vcf=indelNorm.normed_vcf,
			sampleName=nist_sample_name,
			cluster_config=cluster_config,
			disk_size=disk_size
		}

	call ExtractVCFinfo.ExtractVCFinfo as ExtractVCFinfo {
			input:
			nist_snv=SepSnvIndel.nist_snv,
			nist_indel=SepSnvIndel.nist_indel,
			sampleName=nist_sample_name,
			cluster_config=cluster_config,
			disk_size=disk_size
		}

	call oneClass.oneClass as oneClass {
			input:
			snv_vcf=ExtractVCFinfo.snv_vcf,
			indel_vcf=ExtractVCFinfo.indel_vcf,
			snv_train=snv_train,
			indel_train=indel_train,
			kernel=kernel,
			nu=nu,
			sampleName=nist_sample_name,
			cluster_config=cluster_config,
			disk_size=disk_size
		}

	call SepTrueFalse.SepTrueFalse as SepTrueFalse {
			input:
			snv_true_bed=oneClass.snv_true_bed,
			snv_false_bed=oneClass.snv_false_bed,
			indel_true_bed=oneClass.indel_true_bed,
			indel_false_bed=oneClass.indel_false_bed,
			snv_padding=oneClass.snv_padding,
			indel_padding=oneClass.indel_padding,
			snv_gz=SepSnvIndel.nist_snv_gz,
			indel_gz=SepSnvIndel.nist_indel_gz,
			snv_idx=SepSnvIndel.nist_snv_gz_idx,
			indel_idx=SepSnvIndel.nist_indel_gz_idx,
			sampleName=nist_sample_name,
			cluster_config=cluster_config,
			disk_size=disk_size
		}

	call vcfeval.vcfeval as vcfeval {
			input:
			snv_true_vcf=SepTrueFalse.snv_true_vcf,
			snv_true_vcf_index=SepTrueFalse.snv_true_vcf_index,
			snv_false_vcf=SepTrueFalse.snv_false_vcf,
			snv_false_vcf_index=SepTrueFalse.snv_false_vcf_index,
			indel_true_vcf=SepTrueFalse.indel_true_vcf,
			indel_true_vcf_index=SepTrueFalse.indel_true_vcf_index,
			indel_false_vcf=SepTrueFalse.indel_false_vcf,
			indel_false_vcf_index=SepTrueFalse.indel_false_vcf_index,
			giab_bed=giab_bed,
			giab_snv=giab_snv,
			giab_snv_idx=giab_snv_idx,
			giab_indel=giab_indel,
			giab_indel_idx=giab_indel_idx,
			sdf=sdf,
			kernel=kernel,
			nu=nu,
			cluster_config=cluster_config,
			disk_size=disk_size
	}

}
